# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`dmmultipath`](#dmmultipath): A short summary of the purpose of this class
* [`dmmultipath::configure`](#dmmultipathconfigure): Create the directory structure and each config file
* [`dmmultipath::install`](#dmmultipathinstall): Install any necessary packages for DM Multipath
* [`dmmultipath::service`](#dmmultipathservice): Enable the multipathd service and regenerate initramfs (maybe)

## Classes

### dmmultipath

A description of what this class does

#### Examples

##### Default config enabling storwize

```puppet
class { 'dmmultipath':
  enabled_devices => ['ibm_2145'],
}
```

##### Storwize with all options enabled

```puppet
class { 'dmmultipath':
  find_multipaths     => true,
  user_friendly_names => true,
  udev_rules          => true,
  regen_initramfs     => true,
  config_dir          => '/etc/multipath/conf.d',
  udev_rules_dir      => '/etc/udev/rules.d',
  enabled_devices     => ['ibm_2145'],
}
```

#### Parameters

The following parameters are available in the `dmmultipath` class.

##### `find_multipaths`

Data type: `Boolean`

Sets the default parameter 'find_multipaths' to yes or no.

Default value: `false`

##### `user_friendly_names`

Data type: `Boolean`

Sets the default parameter 'user_friendly_names' to yes or no. This controls
whether device alias names like 'mpatha' are automatically created.

Default value: `true`

##### `udev_rules`

Data type: `Boolean`

When enabled any udev rules relevant to enabled device types will be
configured for this system.

Default value: `true`

##### `regen_initramfs`

Data type: `Boolean`

If enabled the initramfs will be regenerated for this machine. Note that
this can be crucial for SAN boot systems as they need multipathing to be up
and running when the system comes online.

Default value: `false`

##### `config_dir`

Data type: `Stdlib::Absolutepath`

Location of the multipath config files which will be read in and combined
with the base '/etc/multipath.conf'. Typically this is
'/etc/multipath/conf.d'.

Default value: '/etc/multipath/conf.d'

##### `udev_rules_dir`

Data type: `Stdlib::Absolutepath`

Location where additional udev rules should be defined. Typically this is
'/etc/udev/rules.d'.

Default value: '/etc/udev/rules.d'

##### `enabled_devices`

Data type: `Array[Dmmultipath::SupportedModels]`

List of device types to enable on this system. Currently only ibm_2145 is
supported by this module.

Default value: `undef`

##### `dev_data`

Data type: `Hash[Dmmultipath::SupportedModels,Dmmultipath::Device]`

This hash contains pre-configured lists of multipath 'device' directives.
If a given device is enabled via $enabled_devices the corresponding values
present in this hash will be used to create a file in the multipath config
directory.

Default value: `undef`

##### `dev_udev_data`

Data type: `Hash[Dmmultipath::SupportedModels,Dmmultipath::DeviceUdev]`

Contains udev parameters for the provided device type. Note that this
currently only supports SCSI timeouts. If udev_rules is enabled rules
corresponding to the devices in $enabled_devices will be generated.

Default value: `undef`

##### `packages`

Data type: `Array[String]`

List of packages which should be installed for proper multipathing
functionality.

Default value: `undef`

### dmmultipath::configure

Private class responsible for creating config files & directory structure

### dmmultipath::install

A simple internal class which manages all install-time steps

### dmmultipath::service

Private class which manages services and other post-config activity.

