# Private class which manages services and other post-config activity.
#
# @summary Enable the multipathd service and regenerate initramfs (maybe)
class dmmultipath::service {
  # Make sure the service is running and configured to start at boot
  service { 'multipathd':
    ensure => 'running',
    enable => true,
  }

  # If this machine is SAN-boot we need to regenerate dracut, but only if we
  # didn't already... 
  if $dmmultipath::regen_initramfs {
    $checksum_file = '/boot/puppet-dmmultipath.md5'
    $cmd_dracut = 'dracut --force --add multipath --include /etc/multipath'
    $cmd_gen_checksum = "md5sum /boot/initramfs-$(uname -r).img > ${checksum_file}"
    $cmd_verify_checksum = "$(md5sum -c ${checksum_file} >/dev/null 2>&1; echo $?)"
    exec { "${cmd_dracut}; ${cmd_gen_checksum}":
      path   => '/sbin:/bin/:usr/sbin:/usr/bin',
      onlyif => "test 0 -ne ${cmd_verify_checksum}",
    }
  }
}
